==> gmalglib-0.1.0.tar.gz: gmalglib-0.1.0/sm3/sm3module.c <==
#define PY_SSIZE_T_CLEAN

#include <Python.h>
#include "sm3.h"

typedef struct _PySM3Object {
    PyObject_HEAD
    SM3 sm3;
} PySM3Object;

static int PySM3_init(PySM3Object* self, PyObject* args, PyObject* kwargs);
static PyObject* PySM3_update(PySM3Object* self, PyObject* args, PyObject* kwargs);
static PyObject* PySM3_digest(PySM3Object* self, PyObject* Py_UNUSED(args));
static PyObject* PySM3_reset(PySM3Object* self, PyObject* Py_UNUSED(args));
static PyObject* PySM3_copy(PySM3Object* self, PyObject* Py_UNUSED(args));

static PyMethodDef py_methods_def_SM3[] = {
    {"update", (PyCFunction)PySM3_update, METH_VARARGS | METH_KEYWORDS, PyDoc_STR("Update internal state with data stream.")},
    {"digest", (PyCFunction)PySM3_digest, METH_NOARGS, PyDoc_STR("Get digest.")},
    {"reset", (PyCFunction)PySM3_reset, METH_NOARGS, PyDoc_STR("Reset internal state to empty.")},
    {"copy", (PyCFunction)PySM3_copy, METH_NOARGS, PyDoc_STR("Copy state to a new object.")},
    {NULL}
};

static PyTypeObject py_type_SM3 = {
    .ob_base = PyVarObject_HEAD_INIT(NULL, 0)
    .tp_name = "sm3.SM3",
    .tp_doc = PyDoc_STR("SM3 Object"),
    .tp_basicsize = sizeof(PySM3Object),
    .tp_itemsize = 0,
    .tp_flags = Py_TPFLAGS_DEFAULT,
    .tp_new = PyType_GenericNew,
    .tp_init = (initproc)PySM3_init,
    .tp_methods = py_methods_def_SM3,
};

static PyModuleDef py_module_def_sm3 = {
    .m_base = PyModuleDef_HEAD_INIT,
    .m_name = "sm3",
    .m_doc = PyDoc_STR("SM3 Algorithm Implemented in C"),
    .m_size = 0,
};

static int PySM3_init(PySM3Object* self, PyObject* args, PyObject* kwargs)
{
    char* keys[] = { "data", NULL };
    Py_buffer py_buffer_data = { 0 };
    int ret = 0;

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|y*:__init__", keys, &py_buffer_data))
        return -1;

    SM3_Init(&self->sm3);

    ret = SM3_Update(&self->sm3, py_buffer_data.buf, py_buffer_data.len);
    PyBuffer_Release(&py_buffer_data);

    if (ret == SM3_ERR_OVERFLOW)
    {
        PyErr_SetString(PyExc_OverflowError, "Data too long.");
        return -1;
    }
    return 0;
}

static PyObject* PySM3_update(PySM3Object* self, PyObject* args, PyObject* kwargs)
{
    char* keys[] = { "data", NULL };
    Py_buffer py_buffer_data = { 0 };
    int ret = 0;

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "y*:update", keys, &py_buffer_data))
        return NULL;

    ret = SM3_Update(&self->sm3, py_buffer_data.buf, py_buffer_data.len);
    PyBuffer_Release(&py_buffer_data);

    if (ret == SM3_ERR_OVERFLOW)
    {
        PyErr_SetString(PyExc_OverflowError, "Data too long.");
        return NULL;
    }

    Py_RETURN_NONE;
}

static PyObject* PySM3_digest(PySM3Object* self, PyObject* Py_UNUSED(args))
{
    uint8_t digest[32] = { 0 };
    SM3_Digest(&self->sm3, digest);

    return PyBytes_FromStringAndSize(digest, 32);
}

static PyObject* PySM3_reset(PySM3Object* self, PyObject* Py_UNUSED(args))
{
    SM3_Init(&self->sm3);
    Py_RETURN_NONE;
}

static PyObject* PySM3_copy(PySM3Object* self, PyObject* Py_UNUSED(args))
{
    PySM3Object* other = PyObject_New(PySM3Object, &py_type_SM3);
    if (!other)
        return NULL;

    other->sm3 = self->sm3;
    return (PyObject*)other;
}

PyMODINIT_FUNC PyInit_sm3() {
    PyObject* py_module = NULL;
    PyObject* py_long_const_1 = NULL;

    if (PyType_Ready(&py_type_SM3) < 0)
        return NULL;

    py_module = PyModule_Create(&py_module_def_sm3);
    if (!py_module)
        goto F0;

    Py_INCREF(&py_type_SM3);
    if (PyModule_AddObject(py_module, "SM3", (PyObject*)&py_type_SM3) < 0)
        goto F1;

    py_long_const_1 = PyLong_FromUnsignedLongLong(SM3_MAX_MSG_BITLEN);
    if (!py_long_const_1)
        goto F1;

    if (PyModule_AddObject(py_module, "SM3_MAX_MSG_BITLEN", py_long_const_1) < 0)
        goto F2;

    return py_module;

F2:
    Py_DECREF(py_long_const_1);
F1:
    Py_DECREF(&py_type_SM3);
    Py_DECREF(py_module);
F0:    
    return NULL;
}

==> gmalglib-0.1.4.tar.gz: gmalglib-0.1.4/sm3/sm3module.c <==
#define PY_SSIZE_T_CLEAN

#include <Python.h>
#include "sm3.h"

typedef struct _PySM3Object {
    PyObject_HEAD
    SM3 sm3;
} PySM3Object;

static int PySM3_init(PySM3Object* self, PyObject* args, PyObject* kwargs);
static PyObject* PySM3_update(PySM3Object* self, PyObject* args, PyObject* kwargs);
static PyObject* PySM3_digest(PySM3Object* self, PyObject* Py_UNUSED(args));
static PyObject* PySM3_reset(PySM3Object* self, PyObject* Py_UNUSED(args));
static PyObject* PySM3_copy(PySM3Object* self, PyObject* Py_UNUSED(args));

static PyMethodDef py_methods_def_SM3[] = {
    {"update", (PyCFunction)PySM3_update, METH_VARARGS | METH_KEYWORDS, PyDoc_STR("Update internal state with data stream.")},
    {"digest", (PyCFunction)PySM3_digest, METH_NOARGS, PyDoc_STR("Get digest.")},
    {"reset", (PyCFunction)PySM3_reset, METH_NOARGS, PyDoc_STR("Reset internal state to empty.")},
    {"copy", (PyCFunction)PySM3_copy, METH_NOARGS, PyDoc_STR("Copy state to a new object.")},
    {NULL}
};

static PyTypeObject py_type_SM3 = {
    .ob_base = PyVarObject_HEAD_INIT(NULL, 0)
    .tp_name = "sm3.SM3",
    .tp_doc = PyDoc_STR("SM3 Object"),
    .tp_basicsize = sizeof(PySM3Object),
    .tp_itemsize = 0,
    .tp_flags = Py_TPFLAGS_DEFAULT,
    .tp_new = PyType_GenericNew,
    .tp_init = (initproc)PySM3_init,
    .tp_methods = py_methods_def_SM3,
};

static PyModuleDef py_module_def_sm3 = {
    .m_base = PyModuleDef_HEAD_INIT,
    .m_name = "sm3",
    .m_doc = PyDoc_STR("SM3 Algorithm Implemented in C"),
    .m_size = 0,
};

static int PySM3_init(PySM3Object* self, PyObject* args, PyObject* kwargs)
{
    char* keys[] = { "data", NULL };
    Py_buffer py_buffer_data = { 0 };
    int ret = 0;

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|y*:__init__", keys, &py_buffer_data))
        return -1;

    SM3_Init(&self->sm3);

    ret = SM3_Update(&self->sm3, py_buffer_data.buf, py_buffer_data.len);
    PyBuffer_Release(&py_buffer_data);

    if (ret == SM3_ERR_OVERFLOW)
    {
        PyErr_SetString(PyExc_OverflowError, "Data too long.");
        return -1;
    }
    return 0;
}

static PyObject* PySM3_update(PySM3Object* self, PyObject* args, PyObject* kwargs)
{
    char* keys[] = { "data", NULL };
    Py_buffer py_buffer_data = { 0 };
    int ret = 0;

    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "y*:update", keys, &py_buffer_data))
        return NULL;

    ret = SM3_Update(&self->sm3, py_buffer_data.buf, py_buffer_data.len);
    PyBuffer_Release(&py_buffer_data);

    if (ret == SM3_ERR_OVERFLOW)
    {
        PyErr_SetString(PyExc_OverflowError, "Data too long.");
        return NULL;
    }

    Py_RETURN_NONE;
}

static PyObject* PySM3_digest(PySM3Object* self, PyObject* Py_UNUSED(args))
{
    uint8_t digest[32] = { 0 };
    SM3_Digest(&self->sm3, digest);

    return PyBytes_FromStringAndSize((char*)digest, 32);
}

static PyObject* PySM3_reset(PySM3Object* self, PyObject* Py_UNUSED(args))
{
    SM3_Init(&self->sm3);
    Py_RETURN_NONE;
}

static PyObject* PySM3_copy(PySM3Object* self, PyObject* Py_UNUSED(args))
{
    PySM3Object* other = PyObject_New(PySM3Object, &py_type_SM3);
    if (!other)
        return NULL;

    other->sm3 = self->sm3;
    return (PyObject*)other;
}

PyMODINIT_FUNC PyInit_sm3() {
    PyObject* py_module = NULL;
    PyObject* py_long_const_1 = NULL;

    if (PyType_Ready(&py_type_SM3) < 0)
        return NULL;

    py_module = PyModule_Create(&py_module_def_sm3);
    if (!py_module)
        goto F0;

    Py_INCREF(&py_type_SM3);
    if (PyModule_AddObject(py_module, "SM3", (PyObject*)&py_type_SM3) < 0)
        goto F1;

    py_long_const_1 = PyLong_FromUnsignedLongLong(SM3_MAX_MSG_BITLEN);
    if (!py_long_const_1)
        goto F1;

    if (PyModule_AddObject(py_module, "SM3_MAX_MSG_BITLEN", py_long_const_1) < 0)
        goto F2;

    return py_module;

F2:
    Py_DECREF(py_long_const_1);
F1:
    Py_DECREF(&py_type_SM3);
    Py_DECREF(py_module);
F0:    
    return NULL;
}
